==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/a8/a86c9f5a41fd1652f1ac4ccbac8d03f0.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/ReportBundle/Event/ReportEvent.php */
class __TwigTemplate_3b519f0b6ab2636fb2912fe9e4031ea9 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\ReportBundle\\Event;

use Mautic\\CoreBundle\\Event\\CommonEvent;
use Mautic\\ReportBundle\\Entity\\Report;

class ReportEvent extends CommonEvent
{
    /**
     * @param bool \$isNew
     */
    public function __construct(Report \$report, \$isNew = false)
    {
        \$this->entity = \$report;
        \$this->isNew  = \$isNew;
    }

    /**
     * Returns the Report entity.
     *
     * @return Report
     */
    public function getReport()
    {
        return \$this->entity;
    }

    /**
     * Sets the Report entity.
     */
    public function setReport(Report \$report): void
    {
        \$this->entity = \$report;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/ReportBundle/Event/ReportEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/ReportBundle/Event/ReportEvent.php", "/var/www/html/mauticGIT-Test/app/bundles/ReportBundle/Event/ReportEvent.php");
    }
}

==> production-demo-20260209_093043.tar.gz: var/www/html/production-demo/var/tmp/twig/a8/a86c9f5a41fd1652f1ac4ccbac8d03f0.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/ReportBundle/Event/ReportEvent.php */
class __TwigTemplate_3b519f0b6ab2636fb2912fe9e4031ea9 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

namespace Mautic\\ReportBundle\\Event;

use Mautic\\CoreBundle\\Event\\CommonEvent;
use Mautic\\ReportBundle\\Entity\\Report;

class ReportEvent extends CommonEvent
{
    /**
     * @param bool \$isNew
     */
    public function __construct(Report \$report, \$isNew = false)
    {
        \$this->entity = \$report;
        \$this->isNew  = \$isNew;
    }

    /**
     * Returns the Report entity.
     *
     * @return Report
     */
    public function getReport()
    {
        return \$this->entity;
    }

    /**
     * Sets the Report entity.
     */
    public function setReport(Report \$report): void
    {
        \$this->entity = \$report;
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/ReportBundle/Event/ReportEvent.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/ReportBundle/Event/ReportEvent.php", "/var/www/html/production-demo/app/bundles/ReportBundle/Event/ReportEvent.php");
    }
}
